@@ -18,6 +18,7 @@ local core = require("apisix.core")
 local consumers = require("apisix.consumer").consumers
 local resource = require("apisix.admin.resource")
 local schema_plugin = require("apisix.admin.plugins").check_schema
+local plugins_encrypt_conf = require("apisix.admin.plugins").encrypt_conf
 local type = type
 local tostring = tostring
 local ipairs = ipairs
@@ -38,6 +39,11 @@ local function check_conf(id, conf, need_id, schema)
 end
 
 
+local function encrypt_conf(id, conf)
+    plugins_encrypt_conf(conf.plugins)
+end
+
+
 local function delete_checker(id)
     local consumers, consumers_ver = consumers()
     if consumers_ver and consumers then
@@ -61,6 +67,7 @@ return resource.new({
     kind = "consumer group",
     schema = core.schema.consumer_group,
     checker = check_conf,
+    encrypt_conf = encrypt_conf,
     unsupported_methods = {"post"},
     delete_checker = delete_checker
 })
