@@ -19,14 +19,15 @@ local resource = require("apisix.admin.resource")
 local stream_route_checker = require("apisix.stream.router.ip_port").stream_route_checker
 
 
-local function check_conf(id, conf, need_id, schema)
+local function check_conf(id, conf, need_id, schema, opts)
+    opts = opts or {}
     local ok, err = core.schema.check(schema, conf)
     if not ok then
         return nil, {error_msg = "invalid configuration: " .. err}
     end
 
     local upstream_id = conf.upstream_id
-    if upstream_id then
+    if upstream_id and not opts.skip_references_check then
         local key = "/upstreams/" .. upstream_id
         local res, err = core.etcd.get(key)
         if not res then
@@ -43,7 +44,7 @@ local function check_conf(id, conf, need_id, schema)
     end
 
     local service_id = conf.service_id
-    if service_id then
+    if service_id and not opts.skip_references_check then
         local key = "/services/" .. service_id
         local res, err = core.etcd.get(key)
         if not res then
