@@ -38,6 +38,11 @@ local function check_conf(id, conf, need_id)
 end
 
 
+local function encrypt_conf(id, conf)
+    apisix_upstream.encrypt_conf(conf)
+end
+
+
 local function up_id_in_plugins(plugins, up_id)
     if plugins and plugins["traffic-split"]
         and plugins["traffic-split"].rules then
@@ -130,5 +135,6 @@ return resource.new({
     kind = "upstream",
     schema = core.schema.upstream,
     checker = check_conf,
+    encrypt_conf = encrypt_conf,
     delete_checker = delete_checker
 })
