@@ -27,8 +27,7 @@ local ipairs = ipairs
 local setmetatable = setmetatable
 local tostring = tostring
 local type = type
-
-
+local ngx_re = require('ngx.re')
 local _M = {}
 
 
@@ -216,4 +215,11 @@ function _M.parse_time_unit(s)
 end
 
 
+function _M.parse_path(resource_full_path)
+    local resource_path_parts = ngx_re.split(resource_full_path, "#")
+    local resource_path = resource_path_parts[1] or resource_full_path
+    local resource_sub_path = resource_path_parts[2] or ""
+    return resource_path, resource_sub_path
+end
+
 return _M
