@@ -516,6 +516,10 @@ function _M.connect(premature, consul_server, retry_delay)
                     end
 
                     local svc_address, svc_port = node.Service.Address, node.Service.Port
+                    -- Handle nil or 0 port case - default to 80 for HTTP services
+                    if not svc_port or svc_port == 0 then
+                        svc_port = 80
+                    end
                     -- if nodes is nil, new nodes table and set to up_services
                     if not nodes then
                         nodes = core.table.new(1, 0)
