@@ -15,9 +15,12 @@
 -- limitations under the License.
 --
 
-local ipairs = ipairs
-local core   = require("apisix.core")
-local http   = require("resty.http")
+local ipairs   = ipairs
+local core     = require("apisix.core")
+local http     = require("resty.http")
+local pairs    = pairs
+local type     = type
+local tostring = tostring
 
 local schema = {
     type = "object",
@@ -41,6 +44,20 @@ local schema = {
             items = {type = "string"},
             description = "client request header that will be sent to the authorization service"
         },
+        extra_headers = {
+            type = "object",
+            minProperties = 1,
+            patternProperties = {
+                ["^[^:]+$"] = {
+                    type = "string",
+                    description = "header value as a string; may contain variables"
+                                  .. "like $remote_addr, $request_uri"
+                }
+            },
+            description = "extra headers sent to the authorization service; "
+                        .. "values must be strings and can include variables"
+                        .. "like $remote_addr, $request_uri."
+        },
         upstream_headers = {
             type = "array",
             default = {},
@@ -102,6 +119,22 @@ function _M.access(conf, ctx)
         auth_headers["Content-Encoding"] = core.request.header(ctx, "content-encoding")
     end
 
+    if conf.extra_headers then
+        for header, value in pairs(conf.extra_headers) do
+            if type(value) == "number" then
+                value = tostring(value)
+            end
+            local resolve_value, err = core.utils.resolve_var(value, ctx.var)
+            if not err then
+                auth_headers[header] = resolve_value
+            end
+            if err then
+                core.log.error("failed to resolve variable in extra header '",
+                                header, "': ",value,": ",err)
+            end
+        end
+    end
+
     -- append headers that need to be get from the client request header
     if #conf.request_headers > 0 then
         for _, header in ipairs(conf.request_headers) do
@@ -118,17 +151,8 @@ function _M.access(conf, ctx)
         method = conf.request_method
     }
 
-    local httpc = http.new()
-    httpc:set_timeout(conf.timeout)
     if params.method == "POST" then
-        local client_body_reader, err = httpc:get_client_body_reader()
-        if client_body_reader then
-            params.body = client_body_reader
-        else
-            core.log.warn("failed to get client_body_reader. err: ", err,
-            " using core.request.get_body() instead")
-            params.body = core.request.get_body()
-        end
+        params.body = core.request.get_body()
     end
 
     if conf.keepalive then
@@ -136,6 +160,9 @@ function _M.access(conf, ctx)
         params.keepalive_pool = conf.keepalive_pool
     end
 
+    local httpc = http.new()
+    httpc:set_timeout(conf.timeout)
+
     local res, err = httpc:request_uri(conf.uri, params)
     if not res and conf.allow_degradation then
         return
