@@ -17,11 +17,9 @@
 local core     = require("apisix.core")
 local jwt      = require("resty.jwt")
 local consumer_mod = require("apisix.consumer")
-local resty_random = require("resty.random")
 local new_tab = require ("table.new")
 local auth_utils = require("apisix.utils.auth")
 
-local ngx_encode_base64 = ngx.encode_base64
 local ngx_decode_base64 = ngx.decode_base64
 local ngx      = ngx
 local sub_str  = string.sub
@@ -131,8 +129,6 @@ local _M = {
 
 
 function _M.check_schema(conf, schema_type)
-    core.log.info("input conf: ", core.json.delay_encode(conf))
-
     local ok, err
     if schema_type == core.schema.TYPE_CONSUMER then
         ok, err = core.schema.check(consumer_schema, conf)
@@ -144,8 +140,9 @@ function _M.check_schema(conf, schema_type)
         return false, err
     end
 
-    if conf.algorithm ~= "RS256" and conf.algorithm ~= "ES256" and not conf.secret then
-        conf.secret = ngx_encode_base64(resty_random.bytes(32, true))
+    if (conf.algorithm == "HS256" or conf.algorithm == "HS512") and not conf.secret then
+        return false, "property \"secret\" is required "..
+                      "when \"algorithm\" is \"HS256\" or \"HS512\""
     elseif conf.base64_secret then
         if ngx_decode_base64(conf.secret) == nil then
             return false, "base64_secret required but the secret is not in base64 format"
@@ -273,7 +270,6 @@ local function find_consumer(conf, ctx)
         core.log.warn("failed to find consumer: ", err or "invalid user key")
         return nil, nil, "Invalid user key in JWT token"
     end
-    core.log.info("consumer: ", core.json.delay_encode(consumer))
 
     local auth_secret, err = get_auth_secret(consumer.auth_conf)
     if not auth_secret then
