@@ -47,7 +47,7 @@ end
 -- we want to control proxy behavior before auth, so put the code under rewrite method
 function _M.rewrite(conf, ctx)
     if not ok then
-        core.log.error("need to build APISIX-Base to support proxy control")
+        core.log.error("need to build APISIX-Runtime to support proxy control")
         return 501
     end
 
