@@ -19,6 +19,7 @@ local ngx = ngx
 local core = require("apisix.core")
 local uuid = require("resty.jit-uuid")
 local nanoid = require("nanoid")
+local ksuid = require("resty.ksuid")
 local math_random = math.random
 local str_byte = string.byte
 local ffi = require "ffi"
@@ -32,7 +33,7 @@ local schema = {
         include_in_response = {type = "boolean", default = true},
         algorithm = {
             type = "string",
-            enum = {"uuid", "nanoid", "range_id"},
+            enum = {"uuid", "nanoid", "range_id", "ksuid"},
             default = "uuid"
         },
         range_id = {
@@ -50,7 +51,10 @@ local schema = {
                     default = "abcdefghijklmnopqrstuvwxyzABCDEFGHIGKLMNOPQRSTUVWXYZ0123456789"
                 }
             },
-            default = {}
+            default = {
+                length = 16,
+                char_set = "abcdefghijklmnopqrstuvwxyzABCDEFGHIGKLMNOPQRSTUVWXYZ0123456789"
+            }
         }
     }
 }
@@ -87,6 +91,10 @@ local function get_request_id(conf)
         return get_range_id(conf.range_id)
     end
 
+    if conf.algorithm == "ksuid" then
+        return ksuid.generate()
+    end
+
     return uuid()
 end
 
